<?php
namespace Claromentis\Mailgun\Model;

$GLOBALS["__65da1b1ec2d6653e8" . "a0ab7848e536215"] = (@$GLOBALS["__65da1b1ec2" . "d6653e8a0ab7" . "848e536215"] ?: array()) + array("_8c57591" . "7cbaedf1" . "e7efae84" . "939402bf" . "f" => base64_decode("U3Viam" . "VjdA=="), "_44e986c04f41a08b56a383c" . "7b3a88ee2" => base64_decode("c2VuZG" . "Vy"), "_97ea09a7faf27c52c6eff69" . "773df1d8a" => base64_decode("dGltZX" . "N0YW1w"), "_9c050c786fc87" . "170cbb84fc6a8b" . "13cb6" => base64_decode("YXR0YWNo" . "bWVudC0="), "_a1e707d02a2" . "36dadebd15a4" . "5e65ebdb6" => base64_decode("YXR0YWNobWVudC1jb3V" . "udA=="), "_d706c160e45" . "bf7434fff82a" . "5976f0e19" => base64_decode("YXJyYXl" . "fa2V5cw" . "=="), "_956cd32298a" . "229f9768f109" . "6f077ace3" => base64_decode("Ym9keS1wbGFpbg=" . "="), "_618a4aeb9fecc4592a4521f34" . "876fa29" => base64_decode("ZnJvbQ=" . "="), "_f39f5346e313e4dd1ac3a7bd8032" . "beda" => base64_decode("c3Vic3RyX2NvbXBhcm" . "U="), "_1d6c68a0262e8fa0bed1215b7224a98" . "e" => base64_decode("cmV" . "jaX" . "BpZ" . "W50"), "_f589476007fa133f457c3ef" . "29ddfa566" => base64_decode("V" . "G" . "8" . "="), "_6e1c717cf3cb" . "f1af982ed74d4" . "336b7f1" => base64_decode("Ym9keS1od" . "G1s"));
use Claromentis\Core\Mail\Receive\Contract\MailAttachment;
use Claromentis\Core\Mail\Receive\Contract\MailMessage;
use Claromentis\Core\Util\ArrayUtil;




class MailgunMessage implements MailMessage
{
    protected $message_data;
    protected $attachments_data;
    protected $attachments;
    
    
    
    
    
    public function __construct($_a3d82c5df38e194c9c73e3ccb4223bbc = [], $_4e7ab34a53ffb13eb0838003f33034d4 = [])
    {
        $this->message_data = $_a3d82c5df38e194c9c73e3ccb4223bbc;
        $this->attachments = $_4e7ab34a53ffb13eb0838003f33034d4;
        foreach ($GLOBALS["__65da1b1ec2d6653e8a0ab7848e53621" . "5"]["_d706c160e45bf7434fff82a597" . "6f0e19"]($this->message_data) as $key) {
            if ($key !== $GLOBALS["__65da1b1ec2d" . "6653e8a0ab784" . "8e536215"]["_a1e707d02a236dadebd15" . "a45e65ebdb6"] && $GLOBALS["__65da1b1ec2d6653e8a0a" . "b7848e536215"]["_f39f5346e313e4d" . "d1ac3a7bd8032bed" . "a"]($key, $GLOBALS["__65da1b1ec2d6653e8a0ab7848e5362" . "15"]["_9c050c786fc87170cbb" . "84fc6a8b13cb6"], 0, 11) === 0) {
                $this->attachments[] = new MailgunAttachmentString($key, $this->message_data[$key]);
            }
        }
    }
    
    
    
    
    public function GetRecipientAddress() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653e8a0ab7848e53621" . "5"]["_1d6c68a0262e8fa" . "0bed1215b7224a98" . "e"]);
    }
    
    
    
    
    
    
    public function GetFrom() : string
    {
        return ArrayUtil::getScalarValue($this->message_data[$GLOBALS["__65da1b1ec2d6653e8a0ab7848" . "e536215"]["_618a4aeb" . "9fecc4592" . "a4521f348" . "76fa29"]], null);
    }
    
    
    
    
    
    
    
    public function GetTo() : string
    {
        return ArrayUtil::getScalarValue($this->message_data[$GLOBALS["__65da1b1ec2d66" . "53e8a0ab7848e53" . "6215"]["_f589476007fa133f457c3ef29ddfa5" . "66"]], null);
    }
    
    
    
    
    public function GetSubject() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653e8a0ab7848e5362" . "15"]["_8c575917" . "cbaedf1e7" . "efae84939" . "402bff"]);
    }
    
    
    
    
    public function GetBodyHtml() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653e8a0ab7848e53621" . "5"]["_6e1c717cf3cbf1af982ed74d433" . "6b7f1"]);
    }
    
    
    
    
    public function GetBodyText() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d" . "6653e8a0ab784" . "8e536215"]["_956cd32298a229" . "f9768f1096f077a" . "ce3"]);
    }
    
    
    
    
    public function GetDate() : \Date
    {
        $_67a0d624aebcceb0abd5ce56a53ff06f = new \Date(ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653e8a0ab7848e5" . "36215"]["_97ea09a7faf27c52c6eff69773df1" . "d8a"]));
        return $_67a0d624aebcceb0abd5ce56a53ff06f;
    }
    
    
    
    
    public function GetSenderAddress() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653e8a" . "0ab7848e536215"]["_44e986c04f41a08b56a383c" . "7b3a88ee2"]);
    }
    public function GetAttachments()
    {
        return $this->attachments;
    }
}