<?php
namespace Claromentis\Infocapture\Subscriber;

$GLOBALS["__65da1b1ec2d6653e8a0ab7848e53621" . "5"] = (@$GLOBALS["__65da1b1ec2d6653e8a0a" . "b7848e536215"] ?: array()) + array("_a3d82c5df38e194c9c73e3ccb422" . "3bbc" => base64_decode("ZW1haWx" . "fZGF0YQ" . "=="), "_c35473364fa7a050299058f332e" . "c29c1" => base64_decode("ZXhjZ" . "XB0aW" . "9u"), "_bfda889b74ea561b14325e30e7d7542" . "6" => base64_decode("Ym9keV9odG" . "1s"), "_376d30c4085" . "7357a4d4cbb1" . "ffaa25817" => base64_decode("dG" . "8="), "_03b1f0cee835582d1158dc" . "e2678b505c" => base64_decode("U3RhcnRpbmcgaW5mb2NhcHR1cmUgbWFpbCByZWNlaXZlZCBzdWJzY3JpYmV" . "y"), "_618a4aeb9fecc4592a4521f34" . "876fa29" => base64_decode("ZnJvb" . "Q=="), "_f656816961e8573806141c558b184fe" . "2" => base64_decode("c3ViamV" . "jdA=="), "_5d40a2cf1c525fb252bf5599e339" . "fdd0" => base64_decode("Tm8gaW5mb2NhcHR1cmUgcHJvamVjdCB3YXMgaWRlbnRpZmllZ" . "CBmb3IgbWFpbDsgc3ViamVjdCAn"), "_67a0d624ae" . "bcceb0abd5c" . "e56a53ff06f" => base64_decode("ZGF0ZQ" . "=="), "_e608e5b5c4c34a" . "67ba97ef84c1e16" . "199" => base64_decode("Jw" . "=="), "_460e1aeb3113" . "a1676ce59a8f4" . "0431d5c" => base64_decode("RmFpbGVkIHRvIHByb2Nlc3MgZW1haWwgZm9yIGluZm9jYXB0dXJlIHByb2pl" . "Y3Q="), "_ced92d7b39128" . "5c8a26846f1f4b" . "d3128" => base64_decode("Ym9keV90" . "ZXh0"), "pro" . "jec" . "t_i" . "d" => base64_decode("cHJv" . "amVj" . "dF9p" . "ZA=="), "_9b16fa2683095e67d7c8" . "b265a8081d0b" => base64_decode("TWFpbFJlY2VpdmVkR" . "XZlbnRSZWNlaXZlcg" . "=="));
use Claromentis\Core\Event\EventDispatcherInterface;
use Claromentis\Core\Event\EventSubscriberInterface;
use Claromentis\Core\Mail\Receive\Event\ReceiveMailEventType;
use Claromentis\Core\Mail\Receive\Event\ReceiveMailEvent;
use Claromentis\Infocapture\Model\MailboxMessage;
use Claromentis\Infocapture\UseCase\GetProjectByEmailAddress;
use Claromentis\Infocapture\UseCase\ProcessEmail;
use Exception;
use Psr\Log\LoggerInterface;
class MailReceivedSubscriber implements EventSubscriberInterface
{
    protected $logger;
    protected $get_project_use_case;
    protected $process_email_use_case;
    public function __construct(LoggerInterface $logger, GetProjectByEmailAddress $_ecd19adac06bcc3637cff9925531a823, ProcessEmail $_33929bbf18079cca22e39e6dbe7eea3c)
    {
        $this->logger = $logger;
        $this->get_project_use_case = $_ecd19adac06bcc3637cff9925531a823;
        $this->process_email_use_case = $_33929bbf18079cca22e39e6dbe7eea3c;
    }
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    public static function getSubscribedEvents()
    {
        return [
            
            
            ReceiveMailEventType::RECEIVE_MAIL => $GLOBALS["__65da1b1ec2d6653e8a0ab7848e536" . "215"]["_9b16fa2" . "683095e6" . "7d7c8b26" . "5a8081d0" . "b"],
        ];
    }
    
    
    
    
    
    
    public function MailReceivedEventReceiver(ReceiveMailEvent $event, $_5693d84b45564f912e36404cbe8957e8, EventDispatcherInterface $_b497ce6f2af10f67516aed0ecf34d8cf)
    {
        $this->logger->info($GLOBALS["__65da1b1ec2d6653e8a0ab7" . "848e536215"]["_03b1f0cee83" . "5582d1158dce" . "2678b505c"]);
        $_a9bf694098bca136cc65bf4d2623bc70 = $event->GetMailMessage();
        $_f656816961e8573806141c558b184fe2 = $_a9bf694098bca136cc65bf4d2623bc70->GetSubject();
        
        
        $project = null;
        if ($_a9bf694098bca136cc65bf4d2623bc70 instanceof MailboxMessage) {
            $project = $_a9bf694098bca136cc65bf4d2623bc70->GetProject();
        } else {
            $project = $this->get_project_use_case->GetMailgunProject($_a9bf694098bca136cc65bf4d2623bc70->GetRecipientAddress());
        }
        if ($project === null) {
            $this->logger->debug($GLOBALS["__65da1b1ec2d6653e8a0ab7848e53621" . "5"]["_5d40a2cf1c5" . "25fb252bf559" . "9e339fdd0"] . $_f656816961e8573806141c558b184fe2 . $GLOBALS["__65da1b1ec2d665" . "3e8a0ab7848e5362" . "15"]["_e608e5b5c4c34a67ba97ef84c1e161" . "99"]);
            return;
        }
        $_a3d82c5df38e194c9c73e3ccb4223bbc = [$GLOBALS["__65da1b1ec2d" . "6653e8a0ab784" . "8e536215"]["_618a4aeb9fec" . "c4592a4521f34" . "876fa29"] => $_a9bf694098bca136cc65bf4d2623bc70->GetSenderAddress(), $GLOBALS["__65da1b1ec2d6653e8a" . "0ab7848e536215"]["_376d30c4085" . "7357a4d4cbb1" . "ffaa25817"] => $_a9bf694098bca136cc65bf4d2623bc70->GetRecipientAddress(), $GLOBALS["__65da1b1ec2d6" . "653e8a0ab7848e" . "536215"]["_f656816" . "961e8573" . "806141c5" . "58b184fe" . "2"] => $_f656816961e8573806141c558b184fe2, $GLOBALS["__65da1b1ec2d" . "6653e8a0ab784" . "8e536215"]["_ced92d7b391285c8a26846f1f4bd31" . "28"] => $_a9bf694098bca136cc65bf4d2623bc70->GetBodyText(), $GLOBALS["__65da1b1ec2d6653e8a0a" . "b7848e536215"]["_bfda889b74" . "ea561b14325" . "e30e7d75426"] => $_a9bf694098bca136cc65bf4d2623bc70->GetBodyHtml(), $GLOBALS["__65da1b1ec2d665" . "3e8a0ab7848e5362" . "15"]["_67a0d624aebcceb0abd5ce56a" . "53ff06f"] => $_a9bf694098bca136cc65bf4d2623bc70->GetDate()];
        try {
            $this->process_email_use_case->ProcessEmail($project, $_a3d82c5df38e194c9c73e3ccb4223bbc, $_a9bf694098bca136cc65bf4d2623bc70->GetAttachments());
        } catch (Exception $_c35473364fa7a050299058f332ec29c1) {
            $this->logger->warning($GLOBALS["__65da1b1ec2d" . "6653e8a0ab784" . "8e536215"]["_460e1aeb3113" . "a1676ce59a8f4" . "0431d5c"], [$GLOBALS["__65da1b1ec2d" . "6653e8a0ab784" . "8e536215"]["project_i" . "d"] => $project->GetId(), $GLOBALS["__65da1b1ec2d6653" . "e8a0ab7848e536215"]["_a3d82c5df38e194c9c73e3ccb4223b" . "bc"] => $_a3d82c5df38e194c9c73e3ccb4223bbc, $GLOBALS["__65da1b1ec2d6653e8a0ab7" . "848e536215"]["_c35473364fa7a050299058f33" . "2ec29c1"] => $_c35473364fa7a050299058f332ec29c1]);
        }
    }
}